JsFuture

Struct JsFuture 

pub struct JsFuture<T = JsValue> { /* private fields */ }
A Rust Future backed by a JavaScript Promise.

This type is constructed with a JavaScript Promise object and translates it to a Rust Future. This type implements the Future trait from the futures crate and will either succeed or fail depending on what happens with the JavaScript Promise.

Currently this type is constructed with JsFuture::from.